@@ -24,8 +24,9 @@
     Copyright:
 
     Parts of this file are direct copies of register defines from the Linux Radeon KMS
-    driver. The file is copyright 2008-2011 Mario Kleiner and also
-    Copyright 2010 Advanced Micro Devices, Inc.
+    and amdgpu KMS driver. The file is copyright 2008-2011 Mario Kleiner, and also for
+    the AMD specific definitions, copyright 2010 - 2017 Advanced Micro Devices, Inc.
+
     Authors: Alex Deucher
 
     License:
@@ -343,6 +344,7 @@
 #       define NI_REGAMMA_PROG_B                       4
 #       define NI_OVL_REGAMMA_MODE(x)                  (((x) & 0x7) << 4)
 
+#define NI_REGAMMA_LUT_WRITE_EN_MASK                       0x6a8C
 #define NI_REGAMMA_LUT_INDEX                               0x6a84
 #define NI_REGAMMA_LUT_DATA                                0x6a88
 
@@ -357,6 +359,50 @@
 #define DCE10_CRTC5_REGISTER_OFFSET                 ((0x459c - 0x1b9c) * 4)
 #define DCE10_CRTC6_REGISTER_OFFSET                 ((0x479c - 0x1b9c) * 4)
 
+// Vega class hardware (DCE-12 display engine):
+#define DCE12_CRTC0_REGISTER_OFFSET                 ((0x06ef - 0x06ef) * 4)
+#define DCE12_CRTC1_REGISTER_OFFSET                 ((0x08ef - 0x06ef) * 4)
+#define DCE12_CRTC2_REGISTER_OFFSET                 ((0x0aef - 0x06ef) * 4)
+#define DCE12_CRTC3_REGISTER_OFFSET                 ((0x0cef - 0x06ef) * 4)
+#define DCE12_CRTC4_REGISTER_OFFSET                 ((0x0eef - 0x06ef) * 4)
+#define DCE12_CRTC5_REGISTER_OFFSET                 ((0x10ef - 0x06ef) * 4)
+
+#define DCE12_DC_LUT_BLACK_OFFSET_BLUE              (0x05c7 * 4)
+#define DCE12_DC_LUT_BLACK_OFFSET_GREEN             (0x05c8 * 4)
+#define DCE12_DC_LUT_BLACK_OFFSET_RED               (0x05c9 * 4)
+#define DCE12_DC_LUT_WHITE_OFFSET_BLUE              (0x05ca * 4)
+#define DCE12_DC_LUT_WHITE_OFFSET_GREEN             (0x05cb * 4)
+#define DCE12_DC_LUT_WHITE_OFFSET_RED               (0x05cc * 4)
+#define DCE12_GRPH_CONTROL                          (0x055b * 4)
+#define DCE12_GRPH_ENABLE                           (0x055a * 4)
+
+#define DCE12_CRTC_V_TOTAL                          (0x06da * 4)
+#define DCE12_CRTC_V_BLANK_START_END                (0x06e0 * 4)
+#define DCE12_CRTC_CONTROL                          (0x06ef * 4)
+#define DCE12_CRTC_BLANK_CONTROL                    (0x06f0 * 4)
+#define DCE12_CRTC_STATUS_POSITION                  (0x06f7 * 4)
+
+// Primary/Secondary scanout buffer start addresses - low 32-Bits:
+#define DCE12_GRPH_PRIMARY_SURFACE_ADDRESS          (0x055e * 4)
+#define DCE12_GRPH_SECONDARY_SURFACE_ADDRESS        (0x055f * 4)
+
+// upper 32-Bits:
+#define DCE12_GRPH_PRIMARY_SURFACE_ADDRESS_HIGH     (0x0561 * 4)
+#define DCE12_GRPH_SECONDARY_SURFACE_ADDRESS_HIGH   (0x0562 * 4)
+
+// Flip status and control:
+#define DCE12_GRPH_UPDATE                           (0x056a * 4)
+
+// DCE-12 dithering control registers: Like on other modern DCEs:
+#define DCE12_FMT_BIT_DEPTH_CONTROL                 (0x0747 * 4)
+
+// DCE-12 regamma table control and content:
+#define DCE12_REGAMMA_LUT_WRITE_EN_MASK             (0x05e3 * 4)
+#define DCE12_REGAMMA_LUT_INDEX                     (0x05e1 * 4)
+#define DCE12_REGAMMA_LUT_DATA                      (0x05e2 * 4)
+#define DCE12_REGAMMA_CONTROL                       (0x05e0 * 4)
+
+
 // NVIDIA REGISTERS:
 // -----------------
 
