@@ -18,7 +18,7 @@ function osxsetoctaverpath(mexfname, mexpath)
 % files should always find a dylib for the currently running Octave.
 
     if ~IsOSX(1) || ~IsOctave
-        error('osxsetoctaverpath only works with a 64-Bit version of HomeBrew Octave-8.2.0 for macOS!');
+        error('osxsetoctaverpath only works with a 64-Bit version of HomeBrew Octave-8.3.0 for macOS!');
     end
 
     % If no mex filename given, iterate over 'mexpath' - or the default install
@@ -31,8 +31,8 @@ function osxsetoctaverpath(mexfname, mexpath)
         d = dir (mexpath);
         for j = 1:length(d)
             if ~d(j).isdir
-                [a, mexfname, extension] = fileparts(d(j).name);
-                if ~isempty(strfind(extension, mexext))
+                [~, mexfname, extension] = fileparts(d(j).name);
+                if ~isempty(strfind(extension, mexext)) %#ok<STREMP> 
                     osxsetoctaverpath(mexfname, mexpath);
                 end
             end
@@ -49,12 +49,12 @@ function osxsetoctaverpath(mexfname, mexpath)
     mexfname = [mexpath mexfname '.' mexext];
 
     % This is how the libdir should be defined automatically:
-    libdir = __octave_config_info__.octlibdir;
+    libdir = GetOctlibDir;
 
-    % This is sadly how we have to do it with Octave on macOS 12 due to
-    % the latest OSX linker crap - Hardcoding the path for a Octave install
+    % This is sadly how we have to do it with Octave on macOS 13 due to
+    % the latest macOS linker crap - Hardcoding the path for a Octave install
     % from HomeBrew. Yes, this is sad...
-    libdir = '/usr/local/opt/octave/lib/octave/8.2.0';
+    libdir = '/usr/local/opt/octave/lib/octave/8.3.0';
 
     % Replace absolute path to liboctinterp.11.dylib with @rpath:
     system(['install_name_tool -change ' libdir '/liboctinterp.11.dylib @rpath/liboctinterp.dylib ' mexfname]);
