@@ -93,6 +93,20 @@ function varargout = PsychTweak(cmd, varargin)
 % MS-Windows only tweaks:
 % -----------------------
 %
+% PsychTweak('DontDisableProcessorIdling', dontDisable);
+% -- Don't disable processor idling during certain Screen() operations, e.g.,
+% during video refresh calibrations and timing startup tests in 'OpenWindow' if
+% 'dontDisable' is set to 1. By default, processor idling is disabled during some
+% tests, to keep cpu cores 100% busy and prevent cpu power management actions like
+% switching to higher C-states, ie. prevent switching to C1 or higher. This causes
+% a temporary increase in system idle power consumption, but reduces timing noise
+% caused by C-state switching, and thereby improves the quality and reliability of
+% the timing tests, hopefully reducing the frequency of "false positive" test
+% failures. However, this could interfere with the operation of other 3rd party
+% cpu performance tweaking tools and other low level tuning measures. Therefore
+% this PsychTweak() setting allows to skip disable of processor idling during tests.
+%
+%
 % PsychTweak('BackwardTimejumpTolerance', secs);
 %
 % -- Allow system clock to report a time that is up to `secs` in the past,
@@ -320,6 +334,27 @@ if strcmpi(cmd, 'UseGPUIndex')
     return;
 end
 
+if strcmpi(cmd, 'DontDisableProcessorIdling')
+    if length(varargin) < 1
+        error('Must provide the dontDisable flag.');
+    end
+
+    val = varargin{1};
+    if ~ismember(val, [0, 1])
+        error('dontDisable flag must be 0 or 1.');
+    end
+
+    if val
+        % Set marker variable:
+        setenv('PSYCH_DONT_DISABLE_CPU_IDLING', '1');
+    else
+        % Delete marker variable:
+        setenv('PSYCH_DONT_DISABLE_CPU_IDLING');
+    end
+
+    return;
+end
+
 % The following routines must be called before any PTB mex files are loaded,
 % otherwise they won't pick up the tweak settings consistently. Check if
 % any ptb mex files are loaded:
