@@ -39,7 +39,9 @@
 %          dhb  Add monochromatic light option to the section that starts with trolands.
 % 8/11/13  dhb  Add test of AborbtanceToAbsorbance.
 %          dhb  Protect against case when absorbance is provided directly.
-
+% 05/26/14 dhb  Dusted off.
+% 6/10/14  npc, dhb  Modifications for accessing calibration data using a @CalStruct object.
+% 7/7/14   dhb  Make calStruct object code conditional on the support routines existing on the path.
 
 %% Clear
 clear; close all;
@@ -78,7 +80,7 @@ photoreceptors = FillInPhotoreceptors(photoreceptors);
 % causes disagreement.
 testAbsorbance = photoreceptors.absorbance;
 testAbsorptance = photoreceptors.absorptance;
-checkAbsorbance = AbsorptanceToAbsorbance(testAbsorptance, photoreceptors.nomogram.S, photoreceptors.axialDensity.value,false);
+checkAbsorbance = AbsorptanceToAbsorbance(testAbsorptance, photoreceptors.nomogram.S, photoreceptors.axialDensity.bleachedValue,false);
 diffs = testAbsorbance-checkAbsorbance;
 if (max(abs(diffs(:))) > 1e-7)
     error('Cannot properly invert absorbance/absorptance computations');
@@ -256,13 +258,31 @@ switch (whichInputType)
 		% Load light radiance.  We'll use a monitor white.
 		% The original units are watts/sr-m^2-wlinterval.
 		cal = LoadCalFile('PTB3TestCal');
-		radianceWattsPerM2Sr = SplineSpd(cal.S_device,sum(cal.P_device,2),S);
-		
+        
+        % If we're running using BrainardLabToolbox and support CalStruct objects, use those.
+        % But if we don't know about those, use old style direct access of fields in cal
+        % structure.  The test is the existance of the routine ObjectToHandleCalOrCalStruct().
+        if (exist('ObjectToHandleCalOrCalStruct','file'))
+            [calStructOBJ, inputArgIsACalStructOBJ] = ObjectToHandleCalOrCalStruct(cal); clear 'cal';
+            P_device = calStructOBJ.get('P_device');
+            S_device = calStructOBJ.get('S');
+            radianceWattsPerM2Sr = SplineSpd(S_device,sum(P_device,2),S);
+        else
+            P_device = cal.P_device;
+            S_device = cal.S_device;
+        end
+        radianceWattsPerM2Sr = SplineSpd(S_device,sum(P_device,2),S);
+        clear S_device P_device
+
 		% Find pupil area, needed to get retinal irradiance.  We compute
 		% pupil area based on the luminance of stimulus according to the
         % algorithm specified in the photoreceptors structure.
 		theXYZ = T_xyz*radianceWattsPerM2Sr; theLuminance = theXYZ(2);
-		[nil,pupilAreaMm2] = PupilDiameterFromLum(theLuminance,photoreceptors.pupilDiameter.source);
+        if (isfield(photoreceptors.pupilDiameter,'value'))
+            pupilAreaMm2 = pi*(photoreceptors.pupilDiameter.value/2).^2;
+        else
+            [nil,pupilAreaMm2] = PupilDiameterFromLum(theLuminance,photoreceptors.pupilDiameter.source);
+        end
         photopicLuminanceCdM2 = T_Y*radianceWattsPerM2Sr;
 		
 		% Convert radiance of source to retinal irradiance and convert to quantal units.
@@ -381,11 +401,19 @@ fprintf('\n');
 if (isfield(photoreceptors.nomogram,'lambdaMax'))
     fprintf('Lambda max                     |\t%8.1f\t%8.1f\t%8.1f\t nm\n',photoreceptors.nomogram.lambdaMax);
 end
-fprintf('Outer Segment Length           |\t%8.1f\t%8.1f\t%8.1f\t um\n',photoreceptors.OSlength.value);
+if (isfield(photoreceptors,'OSlength') && ~isempty(photoreceptors.OSlength.value))
+    fprintf('Outer Segment Length           |\t%8.1f\t%8.1f\t%8.1f\t um\n',photoreceptors.OSlength.value);
+end
+if (isfield(photoreceptors,'OSdiameter') && ~isempty(photoreceptors.OSdiameter.value))
+    fprintf('Outer Segment Diameter         |\t%8.1f\t%8.1f\t%8.1f\t um\n',photoreceptors.OSdiameter.value);
+end
 fprintf('Inner Segment Diameter         |\t%8.1f\t%8.1f\t%8.1f\t um\n',photoreceptors.ISdiameter.value);
 fprintf('\n');
-fprintf('Axial Specific Density         |\t%8.3f\t%8.3f\t%8.3f\t /um\n',photoreceptors.specificDensity.value);
+if (isfield(photoreceptors,'specificDensity') && ~isempty(photoreceptors.specificDensity.value))
+    fprintf('Axial Specific Density         |\t%8.3f\t%8.3f\t%8.3f\t /um\n',photoreceptors.specificDensity.value);
+end
 fprintf('Axial Optical Density          |\t%8.3f\t%8.3f\t%8.3f\n',photoreceptors.axialDensity.value);
+fprintf('Bleached Axial Optical Density |\t%8.3f\t%8.3f\t%8.3f\n',photoreceptors.axialDensity.bleachedValue);
 fprintf('Peak isomerization prob.       |\t%8.3f\t%8.3f\t%8.3f\n',max(photoreceptors.isomerizationAbsorptance,[],2));
 fprintf('______________________________________________________________________________________\n');
 fprintf('\n');
