@@ -298,11 +298,17 @@ try
     modesetting = 'd';
 
     % Which X-Server version is in use?
+    xversion = [0, 0, 0];
     [rc, text] = system('xdpyinfo | grep ''X.Org version''');
     if rc == 0
       xversion = sscanf (text, 'X.Org version: %d.%d.%d');
     else
-      xversion = [0, 0, 0];
+      % No xdpyinfo installed by default, e.g., on RaspberryPi OS, or failed?
+      % Try again at old traditional xorg log location:
+      [rc, text] = system('grep ''X.Org X Server '' /var/log/Xorg.0.log');
+      if rc == 0
+        xversion = sscanf (text, 'X.Org X Server %d.%d.%d');
+      end
     end
 
     % AMD "Sea Islands" gpu with DCE-8 display engine, running under classic ati-ddx?
@@ -541,7 +547,7 @@ end
 % Actually any xorg.conf for non-standard settings needed?
 if noautoaddgpu == 0 && multixscreen == 0 && dri3 == 'd' && ismember(useuxa, ['d', 'n']) && triplebuffer == 'd' && modesetting == 'd' && ...
    ~isempty(intersect(depth30bpp, 'nd')) && ismember(atinotiling, ['d', 'n']) && ~strcmp(xdriver, 'nvidia') && vrrsupport == 'd' && ...
-   needPreventDrmModifiers == 0
+   needPreventDrmModifiers == 0 && ~IsARM
 
   % All settings are for a single X-Screen setup with auto-detected outputs
   % and all driver settings on default and not on a NVidia proprietary driver.
@@ -651,7 +657,7 @@ if noautoaddgpu > 0 || needPreventDrmModifiers
 end
 
 if multixscreen == 0 && dri3 == 'd' && ismember(useuxa, ['d', 'n']) && triplebuffer == 'd' && modesetting == 'd' && ...
-   ~isempty(intersect(depth30bpp, 'nd')) && ismember(atinotiling, ['d', 'n']) && vrrsupport == 'd'
+   ~isempty(intersect(depth30bpp, 'nd')) && ismember(atinotiling, ['d', 'n']) && vrrsupport == 'd' && ~IsARM
   % Done writing the file:
   fclose(fid);
 else
@@ -717,7 +723,7 @@ else
       % On NVidia ddx, tell the driver to also expose HMD's, e.g.,
       % for use with our OpenHMD VR driver, instead of hiding them:
       if strcmp(xdriver, 'nvidia')
-        fprintf(fid, '  Option "AllowHMD"         "yes"\n');
+        fprintf(fid, '  Option "AllowHMD"         "no"\n');
       end
 
       fprintf(fid, 'EndSection\n\n');
@@ -729,7 +735,8 @@ else
     % values for the gpu driving that single X-Screen.
     WriteGPUDeviceSection(fid, xdriver, vrrsupport, dri3, triplebuffer, useuxa, primehacks, [], [], []);
 
-    if ismember('y', depth30bpp) || strcmp(xdriver, 'nvidia')
+    if ismember('y', depth30bpp) || ismember('0', depth30bpp) || strcmp(xdriver, 'nvidia') || ...
+       (strcmp(xdriver, 'modesetting') && IsARM)
       fprintf(fid, 'Section "Screen"\n');
       fprintf(fid, '  Identifier    "Screen%i"\n', 0);
       fprintf(fid, '  Device        "Card%i"\n', 0);
@@ -741,7 +748,7 @@ else
       % On NVidia ddx, tell the driver to also expose HMD's, e.g.,
       % for use with our OpenHMD VR driver, instead of hiding them:
       if strcmp(xdriver, 'nvidia')
-        fprintf(fid, '  Option "AllowHMD"         "yes"\n');
+        fprintf(fid, '  Option "AllowHMD"         "no"\n');
       end
 
       fprintf(fid, 'EndSection\n\n');
@@ -820,6 +827,14 @@ function WriteGPUDeviceSection(fid, xdriver, vrrsupport, dri3, triplebuffer, use
     fprintf(fid, '  Option      "AccelMethod" "%s"\n', useuxa);
   end
 
+  % RaspberryPi with VideoCore4 needs AccelMethod override to glamor, because
+  % RaspberryPi OS 11, as of late 2022, disables glamor, and thereby any
+  % hardware acceleration for OpenGL on VideoCore4 to conserve RAM, something
+  % that doesn't fly with our use case:
+  if strcmp(xdriver, 'modesetting') && IsARM
+    fprintf(fid, '  Option      "AccelMethod" "glamor"\n');
+  end
+
   if strcmp(xdriver, 'ati') && primehacks
     % The ati ddx for old radeon-kms driven AMD cards allows to disable color tiling
     % for the scanout buffer, and that allows us to get good Enduro hybrid graphics
