@@ -45,10 +45,8 @@ function VRInputStuffTest(withHapticFeedback, withMTStressTest, specialReqs, ref
 %
 % The optional parameter 'withGazeTracking', if provided and non-zero, will
 % enable some basic tests of eye gaze tracking with VR HMD's which support
-% eye tracking. Please note that this functionality is not available in
-% official Psychtoolbox releases yet, at least not as of v3.0.19.1, and the
-% api used in this demo is highly experimental and subject to backwards
-% incompatible changes!
+% eye tracking. A setting of 1 will visualize the 2D gaze position, a setting of
+% 2 will visualize a 3D gaze ray in addition.
 %
 % After a keypress (or Enter/Back button press on the controller),
 % visualizes tracked hand position and orientation of hand controllers and
@@ -58,13 +56,14 @@ function VRInputStuffTest(withHapticFeedback, withMTStressTest, specialReqs, ref
 % Tested with XBox controller, Oculus remote, and the two Oculus touch
 % controllers of the Oculus Rift CV-1 on Windows-10 and Linux, with the
 % OculusVR v1 runtime on Windows, and with various OpenXR runtimes like
-% Monado, OculusVR, SteamVR.
+% Monado, OculusVR, SteamVR. Additionally tested with the Vive Wand
+% controllers and builtin binocular eye gaze tracker of a HTC Vive Pro Eye.
 
 % Constants for use in VR applications:
-global OVR; %#ok<GVMIS> 
+global OVR; %#ok<GVMIS>
 
 % GL data structure needed for all OpenGL demos:
-global GL; %#ok<GVMIS> 
+global GL; %#ok<GVMIS>
 
 % No testing of haptic feedback by default, as it sucks up batteries a lot:
 if nargin < 1 || isempty(withHapticFeedback)
@@ -133,7 +132,7 @@ if strcmpi(hmdinfo.type, 'OpenXR') && refSpace
 end
 
 % OpenXR and Use2DViewsWhen3DStopped requested for stopped 3D rendering?
-if strcmpi(hmdinfo.type, 'OpenXR') && ~isempty(strfind(specialReqs, 'Use2DViewsWhen3DStopped')) %#ok<STREMP> 
+if strcmpi(hmdinfo.type, 'OpenXR') && ~isempty(strfind(specialReqs, 'Use2DViewsWhen3DStopped')) %#ok<STREMP>
     % Set some default position for the 2D views that matches kleinerm's
     % eyes well and provides matching imaging geometry between 3D
     % projection layers and 2D quadviews, at least as tested with HTC Vive Pro Eye
@@ -457,7 +456,7 @@ if hmdinfo.handTrackingSupported || withGazeTracking
   % also assign an alpha value that makes the particles "fade out" at the end
   % of there lifetime:
   particlecolors = rand(3, nparticles);
-  
+
   % Maximum speed for particles:
   maxspeed = 1.25;
 
@@ -680,22 +679,10 @@ if hmdinfo.handTrackingSupported || withGazeTracking
         glEnd;
       end
 
-      % Visualize 3D gaze direction if requested, but only in left eye
-      % view, because we only track one gaze ray and viz in both eyes gets
-      % confusing:
+      % Visualize 3D gaze direction if requested:
       if (withGazeTracking >= 2) && (length(state.gazeStatus) >= renderPass + 1) && ...
          (state.gazeStatus(renderPass + 1) >= 3)
-        % Draw an orange wired cone marker to visualize gaze direction by
-        % rendering a complex 3D object in a eye-reference frame specified
-        % coordinate system. We use the global 4x4 OpenGL transformation
-        % matrix provided by gaze tracking:
-        glColor4f(0.17, 0.2, 0, 0.3);
-        glPushMatrix;
-        glMultMatrixd(state.gazeGlobalMat{renderPass + 1});
-        glutWireCone(0.001, 15, 10, 10);
-        glPopMatrix;
-
-        % Draw a 5 meters long green gaze-ray, using the gaze ray equation
+        % Draw a 15 meters long gaze-ray, using the gaze ray equation
         % provided by gaze tracking, ie. global start position of the ray
         % 'tv', corresponding to the the estimated optical center of the
         % eye, and the gaze direction vector 'dv', along the optical axis /
