@@ -51,11 +51,17 @@ if nargin < 1 || isempty(expertmode)
 end
 
 % Which X-Server version is in use?
+xversion = [0, 0, 0];
 [rc, text] = system('xdpyinfo | grep ''X.Org version''');
 if rc == 0
   xversion = sscanf (text, 'X.Org version: %d.%d.%d');
 else
-  xversion = [0, 0, 0];
+  % No xdpyinfo installed by default, e.g., on RaspberryPi OS, or failed?
+  % Try again at old traditional xorg log location:
+  [rc, text] = system('grep ''X.Org X Server '' /var/log/Xorg.0.log');
+  if rc == 0
+    xversion = sscanf (text, 'X.Org X Server %d.%d.%d');
+  end
 end
 
 fprintf('Detected X-Server version %i.%i.%i\n', xversion(1), xversion(2), xversion(3));
@@ -280,6 +286,7 @@ try
   modesetting = 'd';
   usegamma = -1;
   asyncflipsecondaries = 'd';
+  vrhmdondesktop = 0;
 
   if answer == 'n'
     % Nope. Just use the "don't care" settings:
@@ -387,6 +394,29 @@ try
       end
     end
 
+    if strcmp(xdriver, 'nvidia')
+      % Expose VR HMD's on X11 desktop with NVidia proprietary driver? Only useful with
+      % PsychOpenHMDVR and PsychOculusVR:
+      fprintf('\n\nDo you want to use Virtual Reality HMDs of type Rift-DK1/DK2 or with OpenHMD?\n');
+      fprintf('Say yes if you want to drive a Oculus Rift DK1 or DK2, or use other VR HMDs with\n');
+      fprintf('the old OpenHMD VR driver, instead of the modern OpenXR driver. This will expose the\n');
+      fprintf('HMD as regular desktop display on NVidia graphics, so our old OculusVR and OpenHMD\n');
+      fprintf('drivers can use it, preferrably in a multi-X-Screen setup with separate X-Screen for the\n');
+      fprintf('HMD. This will disable any meaningful use of Vulkan displays under NVidia, and disable\n');
+      fprintf('use of VR HMDs with the modern OpenXR driver, e.g., with Monado or SteamVR.\n');
+      fprintf('Answering (n)o or (d)ont care is usually the right choice.\n');
+      vrhmdondesktop = '';
+      while isempty(vrhmdondesktop) || ~ismember(vrhmdondesktop, ['y', 'n', 'd'])
+        vrhmdondesktop = input('Use VR HMD with OpenHMD or OculusVR [y for yes, n for no, d for don''t care]? ', 's');
+      end
+
+      if vrhmdondesktop == 'y'
+        vrhmdondesktop = 1;
+      else
+        vrhmdondesktop = 0;
+      end
+    end
+
     % Use or non-use of modesetting ddx possible on this gpu hardware?
     if expertmode && ~strcmp(xdriver, 'nvidia') && ~strcmp(xdriver, 'modesetting')
         % Yes: The xf86-video-modesetting driver is an option that supports DRI3/Present well.
@@ -482,7 +512,7 @@ end
 % Actually any xorg.conf for non-standard settings needed?
 if noautoaddgpu == 0 && multixscreen == 0 && dri3 == 'd' && modesetting == 'd' && ...
    ~isempty(intersect(depth30bpp, 'nd')) && ~strcmp(xdriver, 'nvidia') && vrrsupport ~= 'y' && ...
-   usegamma == -1 && asyncflipsecondaries ~= 'y'
+   usegamma == -1 && asyncflipsecondaries ~= 'y' && ~IsARM
 
   % All settings are for a single X-Screen setup with auto-detected outputs
   % and all driver settings on default and not on a NVidia proprietary driver.
@@ -552,7 +582,8 @@ if noautoaddgpu > 0
 end
 
 if multixscreen == 0 && dri3 == 'd' && modesetting == 'd' && asyncflipsecondaries ~= 'y' && ...
-   ~isempty(intersect(depth30bpp, 'nd')) && ~strcmp(xdriver, 'nvidia') && vrrsupport ~= 'y' && usegamma == -1
+   ~isempty(intersect(depth30bpp, 'nd')) && (~strcmp(xdriver, 'nvidia') || ~vrhmdondesktop) && ...
+   vrrsupport ~= 'y' && usegamma == -1 && ~IsARM
   % Done writing the file:
   fclose(fid);
 else
@@ -610,9 +641,10 @@ else
         fprintf(fid, '  DefaultDepth  30\n');
       end
 
-      % On NVidia ddx, tell the driver to also expose HMD's, e.g.,
-      % for use with our OpenHMD VR driver, instead of hiding them:
-      if strcmp(xdriver, 'nvidia')
+      % On NVidia ddx, optionally tell the driver to also expose HMD's, e.g.,
+      % for use with our OpenHMD VR driver, instead of hiding them. This will
+      % disable Vulkan direct display mode and modern OpenXR:
+      if strcmp(xdriver, 'nvidia') && vrhmdondesktop
         fprintf(fid, '  Option "AllowHMD"         "yes"\n');
       end
 
@@ -625,7 +657,8 @@ else
     % values for the gpu driving that single X-Screen.
     WriteGPUDeviceSection(fid, xdriver, usegamma, asyncflipsecondaries, vrrsupport, dri3, [], [], []);
 
-    if ismember('y', depth30bpp) || ismember('0', depth30bpp) || strcmp(xdriver, 'nvidia')
+    if ismember('y', depth30bpp) || ismember('0', depth30bpp) || strcmp(xdriver, 'nvidia') || ...
+       (strcmp(xdriver, 'modesetting') && IsARM)
       fprintf(fid, 'Section "Screen"\n');
       fprintf(fid, '  Identifier    "Screen%i"\n', 0);
       fprintf(fid, '  Device        "Card%i"\n', 0);
@@ -634,9 +667,10 @@ else
         fprintf(fid, '  DefaultDepth  30\n');
       end
 
-      % On NVidia ddx, tell the driver to also expose HMD's, e.g.,
-      % for use with our OpenHMD VR driver, instead of hiding them:
-      if strcmp(xdriver, 'nvidia')
+      % On NVidia ddx, optionally tell the driver to also expose HMD's, e.g.,
+      % for use with our OpenHMD VR driver, instead of hiding them. This will
+      % disable Vulkan direct display mode and modern OpenXR:
+      if strcmp(xdriver, 'nvidia') && vrhmdondesktop
         fprintf(fid, '  Option "AllowHMD"         "yes"\n');
       end
 
@@ -696,6 +730,14 @@ function WriteGPUDeviceSection(fid, xdriver, usegamma, asyncflipsecondaries, vrr
     fprintf(fid, '  Option      "DRI" "%s"\n', dri3);
   end
 
+  % RaspberryPi with VideoCore4 needs AccelMethod override to glamor, because
+  % RaspberryPi OS 11, as of late 2022, disables glamor, and thereby any
+  % hardware acceleration for OpenGL on VideoCore4 to conserve RAM, something
+  % that doesn't fly with our use case:
+  if strcmp(xdriver, 'modesetting') && IsARM
+    fprintf(fid, '  Option      "AccelMethod" "glamor"\n');
+  end
+
   % modesetting ddx in use and explicit UseGammaLUT setup wanted?
   if strcmp(xdriver, 'modesetting') && (usegamma ~= -1)
     if usegamma == 1
